==> zio-aws-lightsail_2.12-5.19.7.3-sources.jar: zio/aws/lightsail/model/LoadBalancerTlsCertificateRenewalSummary.scala <==
package zio.aws.lightsail.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class LoadBalancerTlsCertificateRenewalSummary(
    renewalStatus: Optional[
      zio.aws.lightsail.model.LoadBalancerTlsCertificateRenewalStatus
    ] = Optional.Absent,
    domainValidationOptions: Optional[Iterable[
      zio.aws.lightsail.model.LoadBalancerTlsCertificateDomainValidationOption
    ]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lightsail.model.LoadBalancerTlsCertificateRenewalSummary = {
    import LoadBalancerTlsCertificateRenewalSummary.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lightsail.model.LoadBalancerTlsCertificateRenewalSummary
      .builder()
      .optionallyWith(renewalStatus.map(value => value.unwrap))(_.renewalStatus)
      .optionallyWith(
        domainValidationOptions.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.domainValidationOptions)
      .build()
  }
  def asReadOnly
      : zio.aws.lightsail.model.LoadBalancerTlsCertificateRenewalSummary.ReadOnly =
    zio.aws.lightsail.model.LoadBalancerTlsCertificateRenewalSummary
      .wrap(buildAwsValue())
}
object LoadBalancerTlsCertificateRenewalSummary {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lightsail.model.LoadBalancerTlsCertificateRenewalSummary
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.lightsail.model.LoadBalancerTlsCertificateRenewalSummary =
      zio.aws.lightsail.model.LoadBalancerTlsCertificateRenewalSummary(
        renewalStatus.map(value => value),
        domainValidationOptions.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def renewalStatus: Optional[
      zio.aws.lightsail.model.LoadBalancerTlsCertificateRenewalStatus
    ]
    def domainValidationOptions: Optional[List[
      zio.aws.lightsail.model.LoadBalancerTlsCertificateDomainValidationOption.ReadOnly
    ]]
    def getRenewalStatus: ZIO[
      Any,
      AwsError,
      zio.aws.lightsail.model.LoadBalancerTlsCertificateRenewalStatus
    ] = AwsError.unwrapOptionField("renewalStatus", renewalStatus)
    def getDomainValidationOptions: ZIO[Any, AwsError, List[
      zio.aws.lightsail.model.LoadBalancerTlsCertificateDomainValidationOption.ReadOnly
    ]] = AwsError.unwrapOptionField(
      "domainValidationOptions",
      domainValidationOptions
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lightsail.model.LoadBalancerTlsCertificateRenewalSummary
  ) extends zio.aws.lightsail.model.LoadBalancerTlsCertificateRenewalSummary.ReadOnly {
    override val renewalStatus: Optional[
      zio.aws.lightsail.model.LoadBalancerTlsCertificateRenewalStatus
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.renewalStatus())
      .map(value =>
        zio.aws.lightsail.model.LoadBalancerTlsCertificateRenewalStatus
          .wrap(value)
      )
    override val domainValidationOptions: Optional[List[
      zio.aws.lightsail.model.LoadBalancerTlsCertificateDomainValidationOption.ReadOnly
    ]] = zio.aws.core.internal
      .optionalFromNullable(impl.domainValidationOptions())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.lightsail.model.LoadBalancerTlsCertificateDomainValidationOption
            .wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.lightsail.model.LoadBalancerTlsCertificateRenewalSummary
  ): zio.aws.lightsail.model.LoadBalancerTlsCertificateRenewalSummary.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-lightsail_2.13-5.17.104.4-sources.jar: zio/aws/lightsail/model/LoadBalancerTlsCertificateRenewalSummary.scala <==
package zio.aws.lightsail.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class LoadBalancerTlsCertificateRenewalSummary(
    renewalStatus: Option[
      zio.aws.lightsail.model.LoadBalancerTlsCertificateRenewalStatus
    ] = None,
    domainValidationOptions: Option[Iterable[
      zio.aws.lightsail.model.LoadBalancerTlsCertificateDomainValidationOption
    ]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lightsail.model.LoadBalancerTlsCertificateRenewalSummary = {
    import LoadBalancerTlsCertificateRenewalSummary.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lightsail.model.LoadBalancerTlsCertificateRenewalSummary
      .builder()
      .optionallyWith(renewalStatus.map(value => value.unwrap))(_.renewalStatus)
      .optionallyWith(
        domainValidationOptions.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.domainValidationOptions)
      .build()
  }
  def asReadOnly
      : zio.aws.lightsail.model.LoadBalancerTlsCertificateRenewalSummary.ReadOnly =
    zio.aws.lightsail.model.LoadBalancerTlsCertificateRenewalSummary
      .wrap(buildAwsValue())
}
object LoadBalancerTlsCertificateRenewalSummary {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lightsail.model.LoadBalancerTlsCertificateRenewalSummary
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.lightsail.model.LoadBalancerTlsCertificateRenewalSummary =
      zio.aws.lightsail.model.LoadBalancerTlsCertificateRenewalSummary(
        renewalStatus.map(value => value),
        domainValidationOptions.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def renewalStatus: Option[
      zio.aws.lightsail.model.LoadBalancerTlsCertificateRenewalStatus
    ]
    def domainValidationOptions: Option[List[
      zio.aws.lightsail.model.LoadBalancerTlsCertificateDomainValidationOption.ReadOnly
    ]]
    def getRenewalStatus: ZIO[
      Any,
      AwsError,
      zio.aws.lightsail.model.LoadBalancerTlsCertificateRenewalStatus
    ] = AwsError.unwrapOptionField("renewalStatus", renewalStatus)
    def getDomainValidationOptions: ZIO[Any, AwsError, List[
      zio.aws.lightsail.model.LoadBalancerTlsCertificateDomainValidationOption.ReadOnly
    ]] = AwsError.unwrapOptionField(
      "domainValidationOptions",
      domainValidationOptions
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lightsail.model.LoadBalancerTlsCertificateRenewalSummary
  ) extends zio.aws.lightsail.model.LoadBalancerTlsCertificateRenewalSummary.ReadOnly {
    override val renewalStatus: Option[
      zio.aws.lightsail.model.LoadBalancerTlsCertificateRenewalStatus
    ] = scala
      .Option(impl.renewalStatus())
      .map(value =>
        zio.aws.lightsail.model.LoadBalancerTlsCertificateRenewalStatus
          .wrap(value)
      )
    override val domainValidationOptions: Option[List[
      zio.aws.lightsail.model.LoadBalancerTlsCertificateDomainValidationOption.ReadOnly
    ]] = scala
      .Option(impl.domainValidationOptions())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.lightsail.model.LoadBalancerTlsCertificateDomainValidationOption
            .wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.lightsail.model.LoadBalancerTlsCertificateRenewalSummary
  ): zio.aws.lightsail.model.LoadBalancerTlsCertificateRenewalSummary.ReadOnly =
    new Wrapper(impl)
}
